<?php
/**
 * Registering meta boxes
 *
 * All the definitions of meta boxes are listed below with comments.
 * Please read them CAREFULLY.
 *
 * You also should read the changelog to know what has been changed before updating.
 *
 * For more information, please visit:
 * @link http://www.deluxeblogtips.com/meta-box/
 */

add_filter( 'rwmb_meta_boxes', 'gg_register_meta_boxes' );

/**
 * Register meta boxes
 *
 * @return void
 */
function gg_register_meta_boxes( $meta_boxes )
{
        /**
         * Prefix of meta keys (optional)
         * Use underscore (_) at the beginning to make keys hidden
         * Alt.: You also can make prefix empty to disable it
         */
        // Better has an underscore as last sign
        $prefix = 'gg_';

        // General page metabox
        $meta_boxes[] = array(
                // Meta box id, UNIQUE per meta box. Optional since 4.1.5
                'id' => 'general_page_header_meta',

                // Meta box title - Will appear at the drag and drop handle bar. Required.
                'title' => __( 'Page Header Options', 'okthemes' ),

                // Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
                'pages' => array( 'page' ),

                // Where the meta box appear: normal (default), advanced, side. Optional.
                'context' => 'normal',

                // Order of meta box: high (default), low. Optional.
                'priority' => 'high',

                // Auto save: true, false (default). Optional.
                'autosave' => true,

                // List of meta fields
                'fields' => array(
                        array(
                            'name'  => 'Page header',
                            'id'    => "{$prefix}page_header",
                            'desc'  => 'Enable/Disable page header.',
                            'std'   => 1,
                            'type'  => 'checkbox',
                        ),
                        array(
                            'name'  => 'Page title',
                            'id'    => "{$prefix}page_title",
                            'desc'  => 'Enable/Disable page title.',
                            'std'   => 1,
                            'type'  => 'checkbox',
                        ),
                        array(
                            'name'  => 'Breadcrumbs',
                            'id'    => "{$prefix}page_breadcrumbs",
                            'desc'  => 'Enable/Disable page breadcrumbs.',
                            'std'   => 1,
                            'type'  => 'checkbox',
                        ),
                        array(
                            'name'  => 'Page title short description',
                            'id'    => "{$prefix}page_title_short_desc",
                            'desc'  => 'Put your short description here. It will be displayed in a P tag under the title. If you choose not to display the page title, the short description will not be displayed as well.',
                            'type'  => 'text',
                            'std'   => '',
                        ),
                        // SELECT BOX
                        array(
                            'name'     => __( 'Select page heading position', 'okthemes' ),
                            'id'       => "{$prefix}page_heading_pos_select",
                            'type'     => 'select',
                            // Array of 'value' => 'Label' pairs for select box
                            'options'  => array(
                                    'page_heading_left' => __( 'Left', 'okthemes' ),
                                    'page_heading_center' => __( 'Center', 'okthemes' ),
                                    'page_heading_right' => __( 'Right', 'okthemes' ),
                            ),
                            // Select multiple values, optional. Default is false.
                            'multiple'    => false,
                            'std'         => 'page_heading_left',
                            'placeholder' => __( 'Select a position', 'okthemes' ),
                        ),
                                                                       
                ),
                
        );

        // General page metabox
        $meta_boxes[] = array(
                // Meta box id, UNIQUE per meta box. Optional since 4.1.5
                'id' => 'general_page_header_overlay',

                // Meta box title - Will appear at the drag and drop handle bar. Required.
                'title' => __( 'Featured Image Options', 'okthemes' ),

                // Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
                'pages' => array( 'page' ),

                // Where the meta box appear: normal (default), advanced, side. Optional.
                'context' => 'side',

                // Order of meta box: high (default), low. Optional.
                'priority' => 'low',

                // Auto save: true, false (default). Optional.
                'autosave' => true,

                // List of meta fields
                'fields' => array(
                        array(
                            'name'  => 'Apply featured image overlay',
                            'id'    => "{$prefix}page_header_image_overlay",
                            'desc'  => '',
                            'std'   => 0,
                            'type'  => 'checkbox',
                        ),
                                              
                ),
                
        );

        if (is_plugin_active('revslider/revslider.php')) {
        global $wpdb;
        $rs = $wpdb->get_results( 
        "
        SELECT id, title, alias
        FROM ".$wpdb->prefix."revslider_sliders
        ORDER BY id ASC LIMIT 999
        "
        );
        $revsliders = array();
        if ($rs) {
            foreach ( $rs as $slider ) {
              $revsliders[$slider->alias] = $slider->alias;
            }
        } else {
            $revsliders["No sliders found"] = 0;
        }

        // Page header slideshow metabox
        $meta_boxes[] = array(
                // Meta box id, UNIQUE per meta box. Optional since 4.1.5
                'id' => 'general_page_header_slideshow_meta',

                // Meta box title - Will appear at the drag and drop handle bar. Required.
                'title' => __( 'Page Header Slideshow', 'okthemes' ),

                // Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
                'pages' => array( 'page' ),

                // Where the meta box appear: normal (default), advanced, side. Optional.
                'context' => 'normal',

                // Order of meta box: high (default), low. Optional.
                'priority' => 'high',

                // Auto save: true, false (default). Optional.
                'autosave' => true,

                // List of meta fields
                'fields' => array(
                        array(
                            'name'  => 'Page header slider',
                            'id'    => "{$prefix}page_header_slider",
                            'desc'  => 'Enable/Disable page header slider.',
                            'std'   => 0,
                            'type'  => 'checkbox',
                        ),
                        
                        // SELECT BOX
                        array(
                            'name'     => __( 'Select the page header slider', 'okthemes' ),
                            'id'       => "{$prefix}page_header_slider_select",
                            'type'     => 'select',
                            // Array of 'value' => 'Label' pairs for select box
                            'options'  => $revsliders,
                            // Select multiple values, optional. Default is false.
                            'multiple'    => false,
                            'std'         => '',
                            'placeholder' => __( 'Select a slider', 'okthemes' ),
                        ),
                                                                       
                ),
                
        );
        } //end check for rev slider

        // General page metabox
        $meta_boxes[] = array(
                // Meta box id, UNIQUE per meta box. Optional since 4.1.5
                'id' => 'general_page_layout_meta',

                // Meta box title - Will appear at the drag and drop handle bar. Required.
                'title' => __( 'Page Layout Options', 'okthemes' ),

                // Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
                'pages' => array( 'page' ),

                // Where the meta box appear: normal (default), advanced, side. Optional.
                'context' => 'normal',

                // Order of meta box: high (default), low. Optional.
                'priority' => 'high',

                // Auto save: true, false (default). Optional.
                'autosave' => true,

                // List of meta fields
                'fields' => array(
                        
                        // SELECT BOX
                        array(
                            'name'     => __( 'Select the page layout', 'okthemes' ),
                            'id'       => "{$prefix}page_layout_select",
                            'type'     => 'select',
                            // Array of 'value' => 'Label' pairs for select box
                            'options'  => array(
                                    'with_right_sidebar' => __( 'With right sidebar', 'okthemes' ),
                                    'with_left_sidebar' => __( 'With left sidebar', 'okthemes' ),
                                    'no_sidebar' => __( 'No sidebar', 'okthemes' ),
                                    'fullscreen' => __( 'Fullscreen', 'okthemes' ),
                            ),
                            // Select multiple values, optional. Default is false.
                            'multiple'    => false,
                            'std'         => 'with_right_sidebar',
                            'placeholder' => __( 'Select a layout', 'okthemes' ),
                        ),
                        
                ),
                
        );

        
        // General page metabox
        $meta_boxes[] = array(
                // Meta box id, UNIQUE per meta box. Optional since 4.1.5
                'id' => 'general_page_footer_meta',

                // Meta box title - Will appear at the drag and drop handle bar. Required.
                'title' => __( 'Page Footer Options', 'okthemes' ),

                // Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
                'pages' => array( 'page', 'post', 'portfolio_cpt', 'product'),

                // Where the meta box appear: normal (default), advanced, side. Optional.
                'context' => 'normal',

                // Order of meta box: high (default), low. Optional.
                'priority' => 'high',

                // Auto save: true, false (default). Optional.
                'autosave' => true,

                // List of meta fields
                'fields' => array(
                        array(
                            'name'  => 'Page footer message box',
                            'id'    => "{$prefix}page_footer_box",
                            'desc'  => 'Show/Hide page footer message box',
                            'std'   => 0,
                            'type'  => 'checkbox',
                        ),
                        array(
                            'name'  => 'Page footer heading',
                            'id'    => "{$prefix}page_footer_heading",
                            'desc'  => 'Insert your page footer heading here.',
                            'type'  => 'text',
                            'std'   => '',
                        ),
                        array(
                            'name'  => 'Page footer description',
                            'id'    => "{$prefix}page_footer_desc",
                            'desc'  => 'Insert your page footer description here.',
                            'type'  => 'text',
                            'std'   => '',
                        ),
                        array(
                            'name'  => 'First button name',
                            'id'    => "{$prefix}page_footer_first_button_name",
                            'desc'  => 'Insert your page footer button name here.',
                            'type'  => 'text',
                            'std'   => '',
                        ),
                        array(
                            'name'  => 'First button link',
                            'id'    => "{$prefix}page_footer_first_button_link",
                            'desc'  => 'Insert your page footer button link here.',
                            'type'  => 'url',
                            'std'   => '',
                        ),
                        array(
                            'name'  => 'Second button name',
                            'id'    => "{$prefix}page_footer_second_button_name",
                            'desc'  => 'Insert your page footer button name here.',
                            'type'  => 'text',
                            'std'   => '',
                        ),
                        array(
                            'name'  => 'Second button link',
                            'id'    => "{$prefix}page_footer_second_button_link",
                            'desc'  => 'Insert your page footer button link here.',
                            'type'  => 'url',
                            'std'   => '',
                        ),                                               
                ),
                
        );

        
        // Portfolio page metabox
        $meta_boxes[] = array(
                // Meta box id, UNIQUE per meta box. Optional since 4.1.5
                'id' => 'portfolio_page_meta',

                // Meta box title - Will appear at the drag and drop handle bar. Required.
                'title' => __( 'Portfolio Page Options', 'okthemes' ),

                // Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
                'pages' => array( 'page' ),

                // Where the meta box appear: normal (default), advanced, side. Optional.
                'context' => 'normal',

                // Order of meta box: high (default), low. Optional.
                'priority' => 'high',

                // Auto save: true, false (default). Optional.
                'autosave' => true,

                // List of meta fields
                'fields' => array(
                        // TAXONOMY
                        array(
                                'name'    => __( 'Portfolio Category', 'okthemes' ),
                                'id'      => "{$prefix}portfolio_tax",
                                'type'    => 'taxonomy',
                                'options' => array(
                                        // Taxonomy name
                                        'taxonomy' => 'portfolio_category',
                                        // How to show taxonomy: 'checkbox_list' (default) or 'checkbox_tree', 'select_tree', select_advanced or 'select'. Optional
                                        'type' => 'select_advanced',
                                        // Additional arguments for get_terms() function. Optional
                                        'args' => array()
                                ),
                        ),
                        // SELECT BOX
                        array(
                            'name'     => __( 'Display portfolio posts on:', 'okthemes' ),
                            'id'       => "{$prefix}portfolio_col_select",
                            'type'     => 'select',
                            // Array of 'value' => 'Label' pairs for select box
                            'options'  => array(
                                    'four_columns' => __( 'Four columns', 'okthemes' ),
                                    'three_columns' => __( 'Three columns', 'okthemes' ),
                                    'two_columns' => __( 'Two columns', 'okthemes' ),
                                    'one_column' => __( 'One column', 'okthemes' ),
                            ),
                            // Select multiple values, optional. Default is false.
                            'multiple'    => false,
                            'std'         => 'four_columns',
                            'placeholder' => __( 'Select columns', 'okthemes' ),
                        ),
                        // SELECT BOX
                        array(
                            'name'     => __( 'Portfolio posts style:', 'okthemes' ),
                            'id'       => "{$prefix}portfolio_posts_style",
                            'type'     => 'select',
                            // Array of 'value' => 'Label' pairs for select box
                            'options'  => array(
                                    'style_portfolio_overlay' => __( 'Portfolio overlay style', 'okthemes' ),
                                    'style_portfolio_standard' => __( 'Portfolio standard style', 'okthemes' ),
                            ),
                            // Select multiple values, optional. Default is false.
                            'multiple'    => false,
                            'std'         => 'style_portfolio_overlay',
                            'placeholder' => __( 'Select portfolio posts style', 'okthemes' ),
                        ),
                        // CHECKBOX
                        array(
                                'name' => __( 'Display category filter', 'okthemes' ),
                                'id'   => "{$prefix}portfolio_cat_filter",
                                'type' => 'checkbox',
                                // Value can be 0 or 1
                                'std'  => 0,
                        ),
                        array(
                            'name'  => 'Number of posts to display',
                            'id'    => "{$prefix}portfolio_no_posts",
                            'desc'  => 'Enter the number of posts to display before the pagination kicks in. Default: 9',
                            'type'  => 'text',
                            'std'   => '9',
                        ),
                                                                       
                ),
                
        );

        
        // Contact page metabox
        $meta_boxes[] = array(
                // Meta box id, UNIQUE per meta box. Optional since 4.1.5
                'id' => 'contact_page_meta',

                // Meta box title - Will appear at the drag and drop handle bar. Required.
                'title' => __( 'Contact Page Options', 'okthemes' ),

                // Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
                'pages' => array( 'page' ),

                // Where the meta box appear: normal (default), advanced, side. Optional.
                'context' => 'normal',

                // Order of meta box: high (default), low. Optional.
                'priority' => 'high',

                // Auto save: true, false (default). Optional.
                'autosave' => true,

                // List of meta fields
                'fields' => array(
                        array(
                            'name'  => 'Enter your email address',
                            'id'    => "{$prefix}contact_page_email",
                            'desc'  => 'Enter your email address.',
                            'type'  => 'email',
                            'std'   => '',
                        ),
                        array(
                            'name'  => 'Enter success text',
                            'id'    => "{$prefix}contact_page_success_msg",
                            'desc'  => 'Enter the success text',
                            'type'  => 'text',
                            'std'   => 'Your message was sent successfully.',
                        ),
                        array(
                            'name'  => 'Enter error text',
                            'id'    => "{$prefix}contact_page_error_msg",
                            'desc'  => 'Enter the error text',
                            'type'  => 'text',
                            'std'   => 'There was an error submitting the form.',
                        ),
                        array(
                            'name'  => 'reCaptcha',
                            'id'    => "{$prefix}contact_recaptcha",
                            'desc'  => 'Enable/disable recaptcha. Default: false',
                            'std'  => 0,
                            'type'  => 'checkbox',
                        ),
                        array(
                            'name'  => 'reCaptcha private key',
                            'id'    => "{$prefix}contact_recaptcha_private_key",
                            'desc'  => 'Enter your recaptcha private key. Sign up for one <a href="https://www.google.com/recaptcha/admin">here</a>.',
                            'type'  => 'text',
                            'std'   => '',
                        ),
                        array(
                            'name'  => 'reCaptcha public key',
                            'id'    => "{$prefix}contact_recaptcha_public_key",
                            'desc'  => 'Enter your recaptcha public key. Sign up for one <a href="https://www.google.com/recaptcha/admin">here</a>.',
                            'type'  => 'text',
                            'std'   => '',
                        ),
                        array(
                            'name'  => 'Map',
                            'id'    => "{$prefix}contact_map",
                            'desc'  => 'Enable/disable map. Default: true',
                            'std'  => 1,
                            'type'  => 'checkbox',
                        ),
                        array(
                            'name'  => 'Address: Latitude value',
                            'id'    => "{$prefix}contact_map_latitude",
                            'desc'  => 'Enter the latitude value of your location in this format <pre>51.13456</pre> Latitude value is the first string (before comma) of google map address. E.G.: <strong>51.13456</strong>, -1.34333',
                            'type'  => 'text',
                            'std'   => '',
                        ),
                        array(
                            'name'  => 'Address: Longitude value',
                            'id'    => "{$prefix}contact_map_longitude",
                            'desc'  => 'Enter the longitude value of your location in this format <pre>-1.34333</pre> Latitude value is the second string (after comma) of google map address. E.G.: 51.13456, <strong>-1.34333</strong>',
                            'type'  => 'text',
                            'std'   => '',
                        ),
                        array(
                            'name'  => 'Zoom',
                            'id'    => "{$prefix}contact_zoom",
                            'desc'  => 'Enter the zoom level. Default: 10',
                            'type'  => 'text',
                            'std'   => '16',
                        ),
                        array(
                            'name'  => 'Map InfoWindow',
                            'id'    => "{$prefix}contact_map_infowindow",
                            'desc'  => 'Insert your address details. Will appear after you click on the marker icon. HTML supported.',
                            'type'  => 'textarea',
                            'std'   => '',
                        ),
                        array(
                            'name'  => 'Map InfoWindow title',
                            'id'    => "{$prefix}contact_map_infowindow_title",
                            'desc'  => 'Insert the infoWindow title. Will appear only on marker hover.',
                            'type'  => 'text',
                            'std'   => '',
                        )
                                                                       
                ),
                
        );

        // General page metabox img size
        $meta_boxes[] = array(
                // Meta box id, UNIQUE per meta box. Optional since 4.1.5
                'id' => 'general_page_img_info',

                // Meta box title - Will appear at the drag and drop handle bar. Required.
                'title' => __( 'Page featured image size', 'okthemes' ),

                // Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
                'pages' => array( 'page' ),

                // Where the meta box appear: normal (default), advanced, side. Optional.
                'context' => 'side',

                // Order of meta box: high (default), low. Optional.
                'priority' => 'low',

                // Auto save: true, false (default). Optional.
                'autosave' => true,

                // List of meta fields
                'fields' => array(
                        
                        // Description
                        array(
                            'type' => 'description',
                            'name' => __( 'The recommended dimension of the header page image is: 1350x150px. The image is automatically resized, but you must constrain proportions. The width of the image can be bigger but the height must remain at 150px</br>To insert a header image please use the "Set featured image" link from the right panel.', 'okthemes' ),
                            'id'   => 'page_desc_fake_id', // Not used but needed for plugin
                        ),
                ),
                
        );

        // Portfolio post type metabox
        $meta_boxes[] = array(
                // Meta box id, UNIQUE per meta box. Optional since 4.1.5
                'id' => 'portfolio_cpt_meta',

                // Meta box title - Will appear at the drag and drop handle bar. Required.
                'title' => __( 'Portfolio Item Options', 'okthemes' ),

                // Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
                'pages' => array( 'portfolio_cpt' ),

                // Where the meta box appear: normal (default), advanced, side. Optional.
                'context' => 'normal',

                // Order of meta box: high (default), low. Optional.
                'priority' => 'high',

                // Auto save: true, false (default). Optional.
                'autosave' => true,

                // List of meta fields
                'fields' => array(
                        // Portfolio page view
                        array(
                            'type' => 'heading',
                            'name' => __( 'Portfolio page view', 'okthemes' ),
                            'id'   => 'port_page_view_fake_id', // Not used but needed for plugin
                        ),
                        array(
                            'name'  => 'Portfolio item short description',
                            'id'    => "{$prefix}port_item_short_desc",
                            'desc'  => 'Insert a very short item description here. This description will be shown on item hover.',
                            'type'  => 'text',
                            'std'   => '',
                        ),
                        array(
                            'name'              => __( 'Portfolio item lightbox image','okthemes' ),
                            'id'                => "{$prefix}port_item_lightbox_image",
                            'desc'              => 'Upload the image used in lightbox. You can upload as many as you want, but only the first image will be active.',
                            'type'              => 'image_advanced',
                            'max_file_uploads'  => 1,
                        ),
                        array(
                                'name'  => __( 'Custom URL', 'okthemes' ),
                                'id'    => "{$prefix}port_item_custom_url",
                                'desc'  => __( 'Insert a custom URL here. The portfolio item will link to this URL instead of the default one (the one that sends you to the portfolio details page)', 'okthemes' ),
                                'type'  => 'url',
                                'std'   => '',
                        ),

                        array(
                            'type' => 'divider',
                            'id'   => 'page_layout_divider_id', // Not used, but needed
                        ),
                        // Portfolio post view slideshow
                        array(
                            'type' => 'heading',
                            'name' => __( 'Portfolio post view slideshow', 'okthemes' ),
                            'id'   => 'port_post_view_slideshow_fake_id', // Not used but needed for plugin
                        ),
                        array(
                            'name'              => __( 'Portfolio post slideshow images','okthemes' ),
                            'id'                => "{$prefix}port_post_slideshow_image",
                            'desc'              => 'Upload the images used in slideshow.',
                            'type'              => 'image_advanced',
                            'max_file_uploads'  => 50,
                        ),

                        // Portfolio post view meta
                        array(
                            'type' => 'heading',
                            'name' => __( 'Portfolio post view meta', 'okthemes' ),
                            'id'   => 'port_post_view_meta_fake_id', // Not used but needed for plugin
                        ),
                        array(
                            'name'  => 'Description title',
                            'id'    => "{$prefix}port_post_meta_desc_title",
                            'desc'  => 'Put your description title here',
                            'type'  => 'text',
                            'std'   => 'Project Description',
                        ),
                        array(
                                'name' => __( 'Description text', 'okthemes' ),
                                'id'   => "{$prefix}port_post_meta_desc_text",
                                'type' => 'wysiwyg',
                                // Set the 'raw' parameter to TRUE to prevent data being passed through wpautop() on save
                                'raw'  => false,

                                // Editor settings, see wp_editor() function: look4wp.com/wp_editor
                                'options' => array(
                                        'textarea_rows' => 4,
                                        'teeny'         => true,
                                        'media_buttons' => false,
                                ),
                        ),
                        array(
                            'name'  => 'Project button title',
                            'id'    => "{$prefix}port_post_meta_btn_title",
                            'desc'  => 'Put your button title here.',
                            'type'  => 'text',
                            'std'   => 'Launch project',
                        ),
                        array(
                            'name'  => 'Project button URL',
                            'id'    => "{$prefix}port_post_meta_btn_url",
                            'desc'  => 'Put your button URL here.',
                            'type'  => 'url',
                            'std'   => '',
                        ),

                        // Portfolio post ena
                        array(
                            'type' => 'heading',
                            'name' => __( 'Portfolio post enable/disable modules', 'okthemes' ),
                            'id'   => 'port_post_e_d_meta_fake_id', // Not used but needed for plugin
                        ),

                        array(
                            'name'  => 'Post meta',
                            'id'    => "{$prefix}port_post_e_d_meta",
                            'desc'  => 'Enable/Disable post meta (post category and love module). Uncheck to disable.',
                            'std'   => 1,
                            'type'  => 'checkbox',
                        ),

                        array(
                            'name'  => 'Post sharing',
                            'id'    => "{$prefix}port_post_e_d_share",
                            'desc'  => 'Enable/Disable post sharing. Uncheck to disable.',
                            'std'   => 1,
                            'type'  => 'checkbox',
                        ),

                ),
                
        );

        

        // Portfolio page metabox img size
        $meta_boxes[] = array(
                // Meta box id, UNIQUE per meta box. Optional since 4.1.5
                'id' => 'port_page_img_info',

                // Meta box title - Will appear at the drag and drop handle bar. Required.
                'title' => __( 'Portfolio featured image size', 'okthemes' ),

                // Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
                'pages' => array( 'portfolio_cpt' ),

                // Where the meta box appear: normal (default), advanced, side. Optional.
                'context' => 'side',

                // Order of meta box: high (default), low. Optional.
                'priority' => 'low',

                // Auto save: true, false (default). Optional.
                'autosave' => true,

                // List of meta fields
                'fields' => array(
                        // Description
                        array(
                            'type' => 'description',
                            'name' => __( '
                                <strong>Fullwidth layout</strong> <br />
                                1 column  : 1140x713px <br />
                                2 columns : 555x347px <br />
                                3 columns : 360x225px <br />
                                4 columns : 263x164px <br />
                                <strong>Sidebar layout</strong> <br />
                                1 column  : 750x469px <br />
                                2 columns : 360x225px <br />
                                3 columns : 230x144px <br />
                                4 columns : 165x103px <br />
                            ', 'okthemes' ),
                            'id'   => 'port_img_sizes_fake_id', // Not used but needed for plugin
                        ),
                ),
                
        );

        return $meta_boxes;
}

